(function (Drupal) {
  Drupal.behaviors.migrationComplexityReport = {
    attach: function (context) {
      // Debounce function to limit the rate of function execution
      function debounce(func, wait) {
        let timeout;
        return function (...args) {
          const later = () => {
            clearTimeout(timeout);
            func.apply(this, args);
          };
          clearTimeout(timeout);
          timeout = setTimeout(later, wait);
        };
      }

      // Expand/Collapse All Button
      const toggleAllButton = context.querySelector('#toggle-all');
      const reportCards = context.querySelectorAll('.report-card');

      if (toggleAllButton) {
        const updateToggleButton = () => {
          const allCollapsed = [...reportCards].every((card) =>
            !card.querySelector('.report-card-content').classList.contains('expanded')
          );

          toggleAllButton.textContent = allCollapsed ? 'Expand All ▶' : 'Collapse All ▼';
          toggleAllButton.dataset.state = allCollapsed ? 'collapsed' : 'expanded';
        };

        // Toggle individual card
        reportCards.forEach((card) => {
          const header = card.querySelector('.report-card-header');
          const content = card.querySelector('.report-card-content');
          const toggleIcon = header.querySelector('.toggle-icon');

          header.addEventListener('click', debounce(() => {
            content.classList.toggle('expanded');
            toggleIcon.textContent = content.classList.contains('expanded') ? '▼' : '▶';
            updateToggleButton();
          }, 100));
        });

        // Toggle all cards
        toggleAllButton.addEventListener('click', debounce(() => {
          const expand = toggleAllButton.dataset.state === 'collapsed';
          reportCards.forEach((card) => {
            const content = card.querySelector('.report-card-content');
            const toggleIcon = card.querySelector('.toggle-icon');

            if (expand) {
              content.classList.add('expanded');
              toggleIcon.textContent = '▼';
            } else {
              content.classList.remove('expanded');
              toggleIcon.textContent = '▶';
            }
          });
          updateToggleButton();
        }, 100));

        updateToggleButton();
      }

      // Handle toggle for fields within each bundle
      const fieldToggles = context.querySelectorAll('.toggle-fields');
      fieldToggles.forEach((toggle) => {
        const targetId = toggle.dataset.target;
        const target = document.getElementById(targetId);

        if (target && toggle) {
          toggle.addEventListener('click', () => {
            const isHidden = target.style.display === 'none' || !target.style.display;
            target.style.display = isHidden ? 'block' : 'none';
            toggle.textContent = isHidden ? 'Hide Fields' : 'Show Fields';
          });
        }
      });

      // Toggle common and uncommon fields containers
      const toggleFieldsContainers = (headers) => {
        headers.forEach((header) => {
          const toggleIcon = header.querySelector('.toggle-icon');
          const content = header.nextElementSibling;
          if (content) {
            content.style.display = 'none';
            header.addEventListener('click', debounce(() => {
              content.classList.toggle('expanded');
              if (content.classList.contains('expanded')) {
                content.style.display = 'block';
                toggleIcon.textContent = '▼';
              } else {
                content.style.display = 'none';
                toggleIcon.textContent = '▶';
              }
            }, 100));
          }
        });
      };

      const commonFieldsHeaders = context.querySelectorAll('.common-fields > span');
      const uncommonFieldsHeaders = context.querySelectorAll('.uncommon-fields > span');

      toggleFieldsContainers(commonFieldsHeaders);
      toggleFieldsContainers(uncommonFieldsHeaders);
    },
  };
})(Drupal);